
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include <ModemManager.h>
#ifndef __MM_FLAGS_TYPES_H__
#define __MM_FLAGS_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "ModemManager-enums.h" */
GType mm_modem_capability_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_CAPABILITY (mm_modem_capability_get_type ())

/**
 * mm_modem_capability_build_string_from_mask:
 * @mask: bitmask of MMModemCapability values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMModemCapability in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_modem_capability_build_string_from_mask (MMModemCapability mask);
GType mm_modem_access_technology_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_ACCESS_TECHNOLOGY (mm_modem_access_technology_get_type ())

/**
 * mm_modem_access_technology_build_string_from_mask:
 * @mask: bitmask of MMModemAccessTechnology values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMModemAccessTechnology in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_modem_access_technology_build_string_from_mask (MMModemAccessTechnology mask);
GType mm_modem_mode_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_MODE (mm_modem_mode_get_type ())

/**
 * mm_modem_mode_build_string_from_mask:
 * @mask: bitmask of MMModemMode values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMModemMode in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_modem_mode_build_string_from_mask (MMModemMode mask);
GType mm_modem_location_source_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_LOCATION_SOURCE (mm_modem_location_source_get_type ())

/**
 * mm_modem_location_source_build_string_from_mask:
 * @mask: bitmask of MMModemLocationSource values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMModemLocationSource in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_modem_location_source_build_string_from_mask (MMModemLocationSource mask);
GType mm_modem_location_assistance_data_type_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_LOCATION_ASSISTANCE_DATA_TYPE (mm_modem_location_assistance_data_type_get_type ())

/**
 * mm_modem_location_assistance_data_type_build_string_from_mask:
 * @mask: bitmask of MMModemLocationAssistanceDataType values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMModemLocationAssistanceDataType in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_modem_location_assistance_data_type_build_string_from_mask (MMModemLocationAssistanceDataType mask);
GType mm_bearer_ip_family_get_type (void) G_GNUC_CONST;
#define MM_TYPE_BEARER_IP_FAMILY (mm_bearer_ip_family_get_type ())

/**
 * mm_bearer_ip_family_build_string_from_mask:
 * @mask: bitmask of MMBearerIpFamily values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMBearerIpFamily in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_bearer_ip_family_build_string_from_mask (MMBearerIpFamily mask);
GType mm_bearer_allowed_auth_get_type (void) G_GNUC_CONST;
#define MM_TYPE_BEARER_ALLOWED_AUTH (mm_bearer_allowed_auth_get_type ())

/**
 * mm_bearer_allowed_auth_build_string_from_mask:
 * @mask: bitmask of MMBearerAllowedAuth values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMBearerAllowedAuth in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_bearer_allowed_auth_build_string_from_mask (MMBearerAllowedAuth mask);
GType mm_modem_3gpp_facility_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_3GPP_FACILITY (mm_modem_3gpp_facility_get_type ())

/**
 * mm_modem_3gpp_facility_build_string_from_mask:
 * @mask: bitmask of MMModem3gppFacility values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMModem3gppFacility in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_modem_3gpp_facility_build_string_from_mask (MMModem3gppFacility mask);
GType mm_oma_feature_get_type (void) G_GNUC_CONST;
#define MM_TYPE_OMA_FEATURE (mm_oma_feature_get_type ())

/**
 * mm_oma_feature_build_string_from_mask:
 * @mask: bitmask of MMOmaFeature values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMOmaFeature in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_oma_feature_build_string_from_mask (MMOmaFeature mask);
GType mm_modem_firmware_update_method_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_FIRMWARE_UPDATE_METHOD (mm_modem_firmware_update_method_get_type ())

/**
 * mm_modem_firmware_update_method_build_string_from_mask:
 * @mask: bitmask of MMModemFirmwareUpdateMethod values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMModemFirmwareUpdateMethod in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_modem_firmware_update_method_build_string_from_mask (MMModemFirmwareUpdateMethod mask);
GType mm_bearer_apn_type_get_type (void) G_GNUC_CONST;
#define MM_TYPE_BEARER_APN_TYPE (mm_bearer_apn_type_get_type ())

/**
 * mm_bearer_apn_type_build_string_from_mask:
 * @mask: bitmask of MMBearerApnType values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMBearerApnType in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_bearer_apn_type_build_string_from_mask (MMBearerApnType mask);
GType mm_bearer_roaming_allowance_get_type (void) G_GNUC_CONST;
#define MM_TYPE_BEARER_ROAMING_ALLOWANCE (mm_bearer_roaming_allowance_get_type ())

/**
 * mm_bearer_roaming_allowance_build_string_from_mask:
 * @mask: bitmask of MMBearerRoamingAllowance values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MMBearerRoamingAllowance in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 */
gchar *mm_bearer_roaming_allowance_build_string_from_mask (MMBearerRoamingAllowance mask);
G_END_DECLS

#endif /* __MM_FLAGS_TYPES_H__ */

/* Generated data ends here */

